Enum DaemonMode

pub enum DaemonMode {
    Run,
    Start,
    Stop(StopOpts),
    Restart(StopOpts),
    Status,
    ShortStatus,
    STOP,
    CONT,
    KILL,
    Log,
    Logf,
}
You may want to use this as a normal argument, i.e. via FromStr, instead, as then single strings can be passed through. There is more flexibility with the options here, though. XX currently this is also conflating STOP and Stop etc., and does not have up etc. aliases, thus pretty unusable.

Variants



Run

Do not put into background, just run forever in the foreground.



Start

Start daemon into background.



Stop(StopOpts)

Stop daemon running in background (does not stop daemons in run mode, only those in start mode). This subcommand has options.



Restart(StopOpts)

stop (ignoring errors) then start. This subcommand has options.



Status

Report if there is a daemon in start or run mode, together with pid if running and what the desired status is.



ShortStatus

Report if there is a daemon in start or run mode (without additional information).



STOP

Send a STOP signal to (i.e. suspend) the daemon.



CONT

Send a CONT signal to (i.e. continue) the daemon.



KILL

Send a KILL signal to (i.e. terminate right away) the daemon.



Log

Open the current log file in the pager ($PAGER or ‘less’)



Logf

Run tail -f on the current log file