Enum DaemonWant

pub enum DaemonWant {
    Down,
    Up,
    Restart,
}
What state we want the daemon to be in

Variants



Down



Up



Restart

Signals to the daemon that we want it to re-execute itself

Implementations

Source

impl DaemonWant

pub fn wants_exit(self) -> bool

Whether the value warrants exiting from a daemon