Struct ExecutionResult

pub struct ExecutionResult(/* private fields */);

Implementations

Source

impl ExecutionResult

pub fn is_daemon(&self) -> bool

If need to know if in the daemon, e.g. to only conditionally return to main

pub fn daemon_cleanup(self) -> bool

Call this in the main function, after everything in the app has been cleaned up. If this is in the daemon child, it will re-exec the daemon binary if this was a restart action. Otherwise exits, indicating whether this is a daemon context (same as is_daemon).