pub struct RestartOnFailures {
pub restart_on_failures: bool,
pub no_restart_on_failures: bool,
}Fields
restart_on_failures: boolno_restart_on_failures: boolWhether to restart the daemon or not when it crashes (in
start/up mode). Restarting works by forking before running
the work, then re-forking when the child ends in a non-normal
way (exit with an error or by signal). Between restarts, the
parent sleeps a bit, with exponential back-off within a time
range configured by the application. The default restart
behaviour is set by the application; the two options cancel
each other out. Note: debugging crashes will be easiest using
the run mode, which ignores the restart setting (never
restarts).