pub struct StopOpts {
pub hard: bool,
pub soft: bool,
pub wait: bool,
pub timeout_before_sigkill: u32,
}Fields
hard: boolThis stops the daemon via signals, first SIGINT, then SIGKILL. Restarting in this mode takes the new enviroment from the issuer since it works by forking a new daemon. (–hard and –soft are opposites; the default depends on the application.)
soft: boolThis stops the daemon by communicating a wish for termination via shared memory. The daemon may delay the reaction for a long time. Restarting in this mode works by the daemon re-executing itself, meaning it will not pick up environment or command line argument changes. This action returns immediately as it only stores the wish. (–hard and –soft are opposites; the default depends on the application.)
wait: boolWhen doing graceful termination, by default the stop/restart actions do not wait for the daemon to carry it out. This changes the behaviour to wait in that case, too.
timeout_before_sigkill: u32The time in seconds after sending SIGINT before sending SIGKILL
Implementations